==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_entities/partmanufacturer_001/PartManufacturer.java <==

package net.datastream.schemas.mp_entities.partmanufacturer_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.PARTMANUFACTURERID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERPARTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERDRAW" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISPRIMARY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOCUMOTOBOOKID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOCUMOTOPARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTMANUFACTURERID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="manufacturerpartcode_new" type="{http://schemas.datastream.net/MP_fields}CODE50_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partid",
    "manufacturerid",
    "manufacturerpartcode",
    "manufacturerdraw",
    "isprimary",
    "outofservice",
    "partconditiontemplateconditioncode",
    "documotobookid",
    "documotopartid",
    "partmanufacturerid"
})
@XmlRootElement(name = "PartManufacturer")
public class PartManufacturer {

    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "MANUFACTURERPARTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturerpartcode;
    @XmlElement(name = "MANUFACTURERDRAW", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturerdraw;
    @XmlElement(name = "ISPRIMARY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String isprimary;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "DOCUMOTOBOOKID", namespace = "http://schemas.datastream.net/MP_fields")
    protected String documotobookid;
    @XmlElement(name = "DOCUMOTOPARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected String documotopartid;
    @XmlElement(name = "PARTMANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTMANUFACTURERID_Type partmanufacturerid;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "manufacturerpartcode_new")
    protected String manufacturerpartcode_New;

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété manufacturerid.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Définit la valeur de la propriété manufacturerid.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Obtient la valeur de la propriété manufacturerpartcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERPARTCODE() {
        return manufacturerpartcode;
    }

    /**
     * Définit la valeur de la propriété manufacturerpartcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERPARTCODE(String value) {
        this.manufacturerpartcode = value;
    }

    /**
     * Obtient la valeur de la propriété manufacturerdraw.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERDRAW() {
        return manufacturerdraw;
    }

    /**
     * Définit la valeur de la propriété manufacturerdraw.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERDRAW(String value) {
        this.manufacturerdraw = value;
    }

    /**
     * Obtient la valeur de la propriété isprimary.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISPRIMARY() {
        return isprimary;
    }

    /**
     * Définit la valeur de la propriété isprimary.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISPRIMARY(String value) {
        this.isprimary = value;
    }

    /**
     * Obtient la valeur de la propriété outofservice.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Définit la valeur de la propriété outofservice.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Obtient la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Définit la valeur de la propriété partconditiontemplateconditioncode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Obtient la valeur de la propriété documotobookid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDOCUMOTOBOOKID() {
        return documotobookid;
    }

    /**
     * Définit la valeur de la propriété documotobookid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDOCUMOTOBOOKID(String value) {
        this.documotobookid = value;
    }

    /**
     * Obtient la valeur de la propriété documotopartid.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDOCUMOTOPARTID() {
        return documotopartid;
    }

    /**
     * Définit la valeur de la propriété documotopartid.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDOCUMOTOPARTID(String value) {
        this.documotopartid = value;
    }

    /**
     * Obtient la valeur de la propriété partmanufacturerid.
     * 
     * @return
     *     possible object is
     *     {@link PARTMANUFACTURERID_Type }
     *     
     */
    public PARTMANUFACTURERID_Type getPARTMANUFACTURERID() {
        return partmanufacturerid;
    }

    /**
     * Définit la valeur de la propriété partmanufacturerid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTMANUFACTURERID_Type }
     *     
     */
    public void setPARTMANUFACTURERID(PARTMANUFACTURERID_Type value) {
        this.partmanufacturerid = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Obtient la valeur de la propriété manufacturerpartcode_New.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getManufacturerpartcode_New() {
        return manufacturerpartcode_New;
    }

    /**
     * Définit la valeur de la propriété manufacturerpartcode_New.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setManufacturerpartcode_New(String value) {
        this.manufacturerpartcode_New = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_entities/partmanufacturer_001/PartManufacturer.java <==

package net.datastream.schemas.mp_entities.partmanufacturer_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.MANUFACTURERID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.PARTMANUFACTURERID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERPARTCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MANUFACTURERDRAW" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISPRIMARY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OUTOFSERVICE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOCUMOTOBOOKID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DOCUMOTOPARTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTMANUFACTURERID" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="manufacturerpartcode_new" type="{http://schemas.datastream.net/MP_fields}CODE50_Type" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partid",
    "manufacturerid",
    "manufacturerpartcode",
    "manufacturerdraw",
    "isprimary",
    "outofservice",
    "partconditiontemplateconditioncode",
    "documotobookid",
    "documotopartid",
    "partmanufacturerid"
})
@XmlRootElement(name = "PartManufacturer")
public class PartManufacturer {

    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "MANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected MANUFACTURERID_Type manufacturerid;
    @XmlElement(name = "MANUFACTURERPARTCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturerpartcode;
    @XmlElement(name = "MANUFACTURERDRAW", namespace = "http://schemas.datastream.net/MP_fields")
    protected String manufacturerdraw;
    @XmlElement(name = "ISPRIMARY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String isprimary;
    @XmlElement(name = "OUTOFSERVICE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String outofservice;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;
    @XmlElement(name = "DOCUMOTOBOOKID", namespace = "http://schemas.datastream.net/MP_fields")
    protected String documotobookid;
    @XmlElement(name = "DOCUMOTOPARTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected String documotopartid;
    @XmlElement(name = "PARTMANUFACTURERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PARTMANUFACTURERID_Type partmanufacturerid;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "manufacturerpartcode_new")
    protected String manufacturerpartcode_New;

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the manufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public MANUFACTURERID_Type getMANUFACTURERID() {
        return manufacturerid;
    }

    /**
     * Sets the value of the manufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MANUFACTURERID_Type }
     *     
     */
    public void setMANUFACTURERID(MANUFACTURERID_Type value) {
        this.manufacturerid = value;
    }

    /**
     * Gets the value of the manufacturerpartcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERPARTCODE() {
        return manufacturerpartcode;
    }

    /**
     * Sets the value of the manufacturerpartcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERPARTCODE(String value) {
        this.manufacturerpartcode = value;
    }

    /**
     * Gets the value of the manufacturerdraw property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMANUFACTURERDRAW() {
        return manufacturerdraw;
    }

    /**
     * Sets the value of the manufacturerdraw property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMANUFACTURERDRAW(String value) {
        this.manufacturerdraw = value;
    }

    /**
     * Gets the value of the isprimary property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISPRIMARY() {
        return isprimary;
    }

    /**
     * Sets the value of the isprimary property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISPRIMARY(String value) {
        this.isprimary = value;
    }

    /**
     * Gets the value of the outofservice property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOUTOFSERVICE() {
        return outofservice;
    }

    /**
     * Sets the value of the outofservice property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOUTOFSERVICE(String value) {
        this.outofservice = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

    /**
     * Gets the value of the documotobookid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDOCUMOTOBOOKID() {
        return documotobookid;
    }

    /**
     * Sets the value of the documotobookid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDOCUMOTOBOOKID(String value) {
        this.documotobookid = value;
    }

    /**
     * Gets the value of the documotopartid property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDOCUMOTOPARTID() {
        return documotopartid;
    }

    /**
     * Sets the value of the documotopartid property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDOCUMOTOPARTID(String value) {
        this.documotopartid = value;
    }

    /**
     * Gets the value of the partmanufacturerid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTMANUFACTURERID_Type }
     *     
     */
    public PARTMANUFACTURERID_Type getPARTMANUFACTURERID() {
        return partmanufacturerid;
    }

    /**
     * Sets the value of the partmanufacturerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTMANUFACTURERID_Type }
     *     
     */
    public void setPARTMANUFACTURERID(PARTMANUFACTURERID_Type value) {
        this.partmanufacturerid = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Gets the value of the manufacturerpartcode_New property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getManufacturerpartcode_New() {
        return manufacturerpartcode_New;
    }

    /**
     * Sets the value of the manufacturerpartcode_New property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setManufacturerpartcode_New(String value) {
        this.manufacturerpartcode_New = value;
    }

}
